@@ -31,6 +31,7 @@ import (
 	"github.com/spf13/cobra"
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/minikube/cluster"
+	"k8s.io/minikube/pkg/minikube/detect"
 	"k8s.io/minikube/pkg/minikube/driver"
 	"k8s.io/minikube/pkg/minikube/exit"
 	"k8s.io/minikube/pkg/minikube/mustload"
@@ -50,6 +51,7 @@ const (
 // placeholders for flag values
 var (
 	mountIP      string
+	mountPort    uint16
 	mountVersion string
 	mountType    string
 	isKill       bool
@@ -110,7 +112,19 @@ var mountCmd = &cobra.Command{
 		var ip net.IP
 		var err error
 		if mountIP == "" {
-			ip, err = cluster.HostIP(co.CP.Host, co.Config.Name)
+			if detect.IsMicrosoftWSL() {
+				klog.Infof("Selecting IP for WSL. This may be incorrect...")
+				ip, err = func() (net.IP, error) {
+					conn, err := net.Dial("udp", "8.8.8.8:80")
+					if err != nil {
+						return nil, err
+					}
+					defer conn.Close()
+					return conn.LocalAddr().(*net.UDPAddr).IP, nil
+				}()
+			} else {
+				ip, err = cluster.HostIP(co.CP.Host, co.Config.Name)
+			}
 			if err != nil {
 				exit.Error(reason.IfHostIP, "Error getting the host IP address to use from within the VM", err)
 			}
@@ -191,6 +205,9 @@ var mountCmd = &cobra.Command{
 
 		err = cluster.Mount(co.CP.Runner, ip.String(), vmPath, cfg)
 		if err != nil {
+			if rtErr, ok := err.(*cluster.MountError); ok && rtErr.ErrorType == cluster.MountErrorConnect {
+				exit.Error(reason.GuestMountCouldNotConnect, "mount could not connect", rtErr)
+			}
 			exit.Error(reason.GuestMount, "mount failed", err)
 		}
 		out.Step(style.Success, "Successfully mounted {{.sourcePath}} to {{.destinationPath}}", out.V{"sourcePath": hostPath, "destinationPath": vmPath})
@@ -202,6 +219,7 @@ var mountCmd = &cobra.Command{
 
 func init() {
 	mountCmd.Flags().StringVar(&mountIP, "ip", "", "Specify the ip that the mount should be setup on")
+	mountCmd.Flags().Uint16Var(&mountPort, "port", 0, "Specify the port that the mount should be setup on, where 0 means any free port.")
 	mountCmd.Flags().StringVar(&mountType, "type", nineP, "Specify the mount filesystem type (supported types: 9p)")
 	mountCmd.Flags().StringVar(&mountVersion, "9p-version", defaultMountVersion, "Specify the 9p version that the mount should use")
 	mountCmd.Flags().BoolVar(&isKill, "kill", false, "Kill the mount process spawned by minikube start")
@@ -212,9 +230,9 @@ func init() {
 	mountCmd.Flags().IntVar(&mSize, "msize", defaultMsize, "The number of bytes to use for 9p packet payload")
 }
 
-// getPort asks the kernel for a free open port that is ready to use
+// getPort uses the requested port or asks the kernel for a free open port that is ready to use
 func getPort() (int, error) {
-	addr, err := net.ResolveTCPAddr("tcp", "localhost:0")
+	addr, err := net.ResolveTCPAddr("tcp", fmt.Sprintf("localhost:%d", mountPort))
 	if err != nil {
 		panic(err)
 	}
