@@ -31,24 +31,7 @@ install_minikube() {
 	sudo install ./out/minikube /usr/local/bin/minikube
 }
 
-install_gh() {
-	export access_token="$1"
-
-	# Make sure gh is installed and configured
-	./hack/jenkins/installers/check_install_gh.sh
-}
-
-config_git() {
-	git config user.name "minikube-bot"
-	git config user.email "minikube-bot@google.com"
-}
-
-create_branch() {
-	git checkout -b addTimeToK8s"$1"
-}
-
 run_benchmark() {
-	pwd
 	( cd ./hack/benchmark/time-to-k8s/time-to-k8s-repo/ &&
 		git submodule update --init &&
 		go run . --config local-kubernetes.yaml --iterations 10 --output output.csv )
@@ -59,30 +42,19 @@ generate_chart() {
 }
 
 create_page() {
-	printf -- "---\ntitle: \"%s Benchmark\"\nlinkTitle: \"%s Benchmark\"\nweight: 1\n---\n\n![time-to-k8s](/images/benchmarks/timeToK8s/%s.png)\n" "$1" "$1" "$1" > ./site/content/en/docs/benchmarks/timeToK8s/"$1".md
+	printf -- "---\ntitle: \"%s Benchmark\"\nlinkTitle: \"%s Benchmark\"\nweight: -$(date +'%Y%m%d')\n---\n\n![time-to-k8s](/images/benchmarks/timeToK8s/%s.png)\n" "$1" "$1" "$1" > ./site/content/en/docs/benchmarks/timeToK8s/"$1".md
 }
 
-commit_changes() {
-	git add ./site/static/images/benchmarks/timeToK8s/"$1".png ./site/content/en/docs/benchmarks/timeToK8s/"$1".md
-	git commit -m "add time-to-k8s benchmark for $1"
-}
-
-create_pr() {
-	git remote add minikube-bot https://minikube-bot:"$2"@github.com/minikube-bot/minikube.git
-	git push -u minikube-bot addTimeToK8s"$1"
-	gh pr create --repo kubernetes/minikube --base master --title "Add time-to-k8s benchmark for $1" --body "Updating time-to-k8s benchmark as part of the release process"
+cleanup() {
+	rm ./hack/benchmark/time-to-k8s/time-to-k8s-repo/output.csv
 }
 
 install_kind
 install_k3d
 install_minikube
-install_gh "$1"
-config_git
 
 VERSION=$(minikube version --short)
-create_branch "$VERSION"
 run_benchmark
 generate_chart "$VERSION"
 create_page "$VERSION"
-commit_changes "$VERSION"
-create_pr "$VERSION" "$1"
+cleanup
