@@ -20,7 +20,6 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path"
@@ -161,7 +160,7 @@ func (e *execRunner) Copy(f assets.CopyableFile) error {
 
 	if e.sudo {
 		// write to temp location ...
-		tmpfile, err := ioutil.TempFile("", "minikube")
+		tmpfile, err := os.CreateTemp("", "minikube")
 		if err != nil {
 			return errors.Wrapf(err, "error creating tempfile")
 		}
