@@ -21,10 +21,11 @@ import (
 	"crypto/md5"
 	"encoding/hex"
 	"fmt"
-	"io/ioutil"
 	"net/http"
 	"os"
+	"path"
 	"path/filepath"
+	"strings"
 
 	"cloud.google.com/go/storage"
 	"google.golang.org/api/option"
@@ -89,7 +90,7 @@ func TarballPath(k8sVersion, containerRuntime string) string {
 
 // remoteTarballURL returns the URL for the remote tarball in GCS
 func remoteTarballURL(k8sVersion, containerRuntime string) string {
-	return fmt.Sprintf("https://storage.googleapis.com/%s/%s", PreloadBucket, TarballName(k8sVersion, containerRuntime))
+	return fmt.Sprintf("https://%s/%s/%s", downloadHost, PreloadBucket, TarballName(k8sVersion, containerRuntime))
 }
 
 func setPreloadState(k8sVersion, containerRuntime string, value bool) {
@@ -188,7 +189,7 @@ func Preload(k8sVersion, containerRuntime, driverName string) error {
 	if err != nil {
 		klog.Warningf("No checksum for preloaded tarball for k8s version %s: %v", k8sVersion, err)
 		realPath = targetPath
-		tmp, err := ioutil.TempFile(targetDir(), TarballName(k8sVersion, containerRuntime)+".*")
+		tmp, err := os.CreateTemp(targetDir(), TarballName(k8sVersion, containerRuntime)+".*")
 		if err != nil {
 			return errors.Wrap(err, "tempfile")
 		}
@@ -245,7 +246,7 @@ var getChecksum = func(k8sVersion, containerRuntime string) ([]byte, error) {
 // saveChecksumFile saves the checksum to a local file for later verification
 func saveChecksumFile(k8sVersion, containerRuntime string, checksum []byte) error {
 	klog.Infof("saving checksum for %s ...", TarballName(k8sVersion, containerRuntime))
-	return ioutil.WriteFile(PreloadChecksumPath(k8sVersion, containerRuntime), checksum, 0o644)
+	return os.WriteFile(PreloadChecksumPath(k8sVersion, containerRuntime), checksum, 0o644)
 }
 
 // verifyChecksum returns true if the checksum of the local binary matches
@@ -253,13 +254,13 @@ func saveChecksumFile(k8sVersion, containerRuntime string, checksum []byte) erro
 func verifyChecksum(k8sVersion, containerRuntime, path string) error {
 	klog.Infof("verifying checksumm of %s ...", path)
 	// get md5 checksum of tarball path
-	contents, err := ioutil.ReadFile(path)
+	contents, err := os.ReadFile(path)
 	if err != nil {
 		return errors.Wrap(err, "reading tarball")
 	}
 	checksum := md5.Sum(contents)
 
-	remoteChecksum, err := ioutil.ReadFile(PreloadChecksumPath(k8sVersion, containerRuntime))
+	remoteChecksum, err := os.ReadFile(PreloadChecksumPath(k8sVersion, containerRuntime))
 	if err != nil {
 		return errors.Wrap(err, "reading checksum file")
 	}
@@ -283,3 +284,29 @@ var ensureChecksumValid = func(k8sVersion, containerRuntime, targetPath string,
 
 	return nil
 }
+
+// CleanUpOlderPreloads deletes preload files beloning to older minikube versions
+// checks the current preload version and then if the saved tar file is belongs to older minikube it will delete it
+// in case of failure only logs to the user
+func CleanUpOlderPreloads() {
+	files, err := os.ReadDir(targetDir())
+	if err != nil {
+		klog.Warningf("Failed to list preload files: %v", err)
+	}
+
+	for _, file := range files {
+		splited := strings.Split(file.Name(), "-")
+		if len(splited) < 4 {
+			continue
+		}
+		ver := splited[3]
+		if ver != PreloadVersion {
+			fn := path.Join(targetDir(), file.Name())
+			klog.Infof("deleting older generation preload %s", fn)
+			err := os.Remove(fn)
+			if err != nil {
+				klog.Warningf("Failed to clean up older preload files, consider running `minikube delete --all --purge`")
+			}
+		}
+	}
+}
